@@ -916,7 +916,7 @@ class CoreManager(Protocol):
     async def connect_to_plugin(self, plugin_name: str) -> "Optional[PluginInterface]": ...
     async def get_ffmpeg_path(self) -> str: ...
     async def get_hwaccel_info(
-        self, target_codec: Union[Literal["h264"], Literal["h265"]]
+        self, target_codec: Union[Literal["h264"], Literal["h265"]], full_hardware: Optional[bool] = None
     ) -> "FfmpegArgs": ...
     async def get_server_addresses(self) -> list[str]: ...
     async def get_ice_servers(self) -> list["IceServer"]: ...
